@@ -5,10 +5,12 @@ mcalinfct <-
            mmm.data=model$model,
            formula.in=terms(model),
            linfct.Means=
-           multcomp:::meanslinfct(model, focus, mmm.data, formula.in),
+           ## multcomp:::meanslinfct(
+           meanslinfct.hh(  ## temporary until meanslinfct is changed
+                          model, focus, mmm.data, formula.in,
+                          contrasts.arg=model$contrasts),
            type="Tukey"
            ) {
-
     lev <- levels(mmm.data[[focus]])
     names(lev) <- lev
     mca <- contrMat(lev, type)
@@ -22,3 +24,5 @@ mcalinfct <-
 ##     mca
   }
 ,s={})
+
+## source("~/HH-R.package/HH/R/mcalinfct.R")
